@@ -9,6 +9,7 @@ from hypothesis.errors import Unsatisfiable
 from hypothesis.internal.reflection import proxies
 from hypothesis_jsonschema._canonicalise import HypothesisRefResolutionError
 
+from .auth import get_auth_storage_from_test
 from .constants import DEFAULT_DEADLINE, DataGenerationMethod
 from .exceptions import InvalidSchema
 from .hooks import GLOBAL_HOOK_DISPATCHER, HookContext, HookDispatcher
@@ -28,7 +29,10 @@ def create_test(
 ) -> Callable:
     """Create a Hypothesis test."""
     hook_dispatcher = getattr(test, "_schemathesis_hooks", None)
-    strategy = operation.as_strategy(hooks=hook_dispatcher, data_generation_method=data_generation_method)
+    auth_storage = get_auth_storage_from_test(test)
+    strategy = operation.as_strategy(
+        hooks=hook_dispatcher, auth_storage=auth_storage, data_generation_method=data_generation_method
+    )
     _given_kwargs = (_given_kwargs or {}).copy()
     _given_kwargs.setdefault("case", strategy)
 
@@ -85,7 +89,7 @@ def add_examples(test: Callable, operation: APIOperation, hook_dispatcher: Optio
         # Unsatisfiable:
         # The underlying schema is not satisfiable and test will raise an error for the same reason.
         # Skipping this exception here allows us to continue the testing process for other operations.
-        # Still, we allow to run user-defined hooks
+        # Still, we allow running user-defined hooks
         examples = []
     context = HookContext(operation)  # context should be passed here instead
     GLOBAL_HOOK_DISPATCHER.dispatch("before_add_examples", context, examples)
