@@ -1,4 +1,4 @@
-# pylint: disable=too-many-lines
+# pylint: disable=too-many-lines,redefined-outer-name
 import enum
 import os
 import sys
@@ -6,12 +6,13 @@ import traceback
 from collections import defaultdict
 from enum import Enum
 from queue import Queue
-from typing import Any, Callable, Dict, Generator, Iterable, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Generator, Iterable, List, NoReturn, Optional, Tuple, Union
 from urllib.parse import urlparse
 
 import attr
 import click
 import hypothesis
+import requests
 import yaml
 
 from .. import checks as checks_module
@@ -36,7 +37,7 @@ from ..specs.graphql.schemas import GraphQLSchema
 from ..specs.openapi import loaders as oas_loaders
 from ..stateful import Stateful
 from ..targets import Target
-from ..types import Filter, RequestCert
+from ..types import Filter, PathLike, RequestCert
 from ..utils import GenericResponse, file_exists, get_requests_auth, import_app
 from . import callbacks, cassettes, output
 from .constants import DEFAULT_WORKERS, MAX_WORKERS, MIN_WORKERS
@@ -44,7 +45,7 @@ from .context import ExecutionContext, ServiceContext
 from .debug import DebugOutputHandler
 from .handlers import EventHandler
 from .junitxml import JunitXMLHandler
-from .options import CSVOption, CustomHelpMessageChoice, NotSet, OptionalInt
+from .options import CsvChoice, CsvEnumChoice, CustomHelpMessageChoice, NotSet, OptionalInt
 
 try:
     from yaml import CSafeLoader as SafeLoader
@@ -61,12 +62,20 @@ CONTEXT_SETTINGS = {"help_option_names": ["-h", "--help"]}
 
 DEFAULT_CHECKS_NAMES = _get_callable_names(checks_module.DEFAULT_CHECKS)
 ALL_CHECKS_NAMES = _get_callable_names(checks_module.ALL_CHECKS)
-CHECKS_TYPE = click.Choice((*ALL_CHECKS_NAMES, "all"))
+CHECKS_TYPE = CsvChoice((*ALL_CHECKS_NAMES, "all"))
 
 DEFAULT_TARGETS_NAMES = _get_callable_names(targets_module.DEFAULT_TARGETS)
 ALL_TARGETS_NAMES = _get_callable_names(targets_module.ALL_TARGETS)
 TARGETS_TYPE = click.Choice((*ALL_TARGETS_NAMES, "all"))
 
+DATA_GENERATION_METHOD_TYPE = click.Choice([item.name for item in DataGenerationMethod])
+
+DEPRECATED_CASSETTE_PATH_OPTION_WARNING = (
+    "Warning: Option `--store-network-log` is deprecated and will be removed in Schemathesis 4.0. "
+    "Use `--cassette-path` instead."
+)
+CASSETTES_PATH_INVALID_USAGE_MESSAGE = "Can't use `--store-network-log` and `--cassette-path` simultaneously"
+
 
 def register_target(function: Target) -> Target:
     """Register a new testing target for schemathesis CLI.
@@ -197,10 +206,18 @@ with_request_cert_key = click.option(
     show_default=False,
     callback=callbacks.validate_request_cert_key,
 )
+with_hosts_file = click.option(
+    "--hosts-file",
+    help="Path to a file to store the Schemathesis.io auth configuration.",
+    type=click.Path(dir_okay=False, writable=True),
+    default=service.DEFAULT_HOSTS_PATH,
+    envvar=service.HOSTS_PATH_ENV_VAR,
+)
 
 
 @schemathesis.command(short_help="Perform schemathesis test.", cls=CommandWithCustomHelp)
-@click.argument("schema", type=str, callback=callbacks.validate_schema)
+@click.argument("schema", type=str)
+@click.argument("api_slug", type=str, required=False)
 @click.option(
     "--checks",
     "-c",
@@ -210,6 +227,7 @@ with_request_cert_key = click.option(
     default=DEFAULT_CHECKS_NAMES,
     cls=GroupedOption,
     group=ParameterGroup.validation,
+    callback=callbacks.convert_checks,
     show_default=True,
 )
 @click.option(
@@ -217,7 +235,7 @@ with_request_cert_key = click.option(
     "-D",
     "data_generation_methods",
     help="Defines how Schemathesis generates data for tests.",
-    type=click.Choice([item.name for item in DataGenerationMethod]),
+    type=DATA_GENERATION_METHOD_TYPE,
     default=DataGenerationMethod.default(),
     callback=callbacks.convert_data_generation_method,
     show_default=True,
@@ -354,7 +372,7 @@ with_request_cert_key = click.option(
     "--validate-schema",
     help="Enable or disable validation of input schema.",
     type=bool,
-    default=True,
+    default=False,
     show_default=True,
     cls=GroupedOption,
     group=ParameterGroup.validation,
@@ -392,6 +410,9 @@ with_request_cert_key = click.option(
     default=CodeSampleStyle.default().name,
     callback=callbacks.convert_code_sample_style,
 )
+@click.option(
+    "--cassette-path", help="Save test results as a VCR-compatible cassette.", type=click.File("w", encoding="utf-8")
+)
 @click.option(
     "--store-network-log", help="Store requests and responses into a file.", type=click.File("w", encoding="utf-8")
 )
@@ -405,6 +426,7 @@ with_request_cert_key = click.option(
     "--stateful",
     help="Utilize stateful testing capabilities.",
     type=click.Choice([item.name for item in Stateful]),
+    default=Stateful.links.name,
     callback=callbacks.convert_stateful,
 )
 @click.option(
@@ -421,6 +443,13 @@ with_request_cert_key = click.option(
     help="Force Schemathesis to parse the input schema with the specified spec version.",
     type=click.Choice(["20", "30"]),
 )
+@click.option(
+    "--hypothesis-database",
+    help="Implementation of a Hypothesis database.",
+    type=str,
+    cls=GroupedOption,
+    group=ParameterGroup.hypothesis,
+)
 @click.option(
     "--hypothesis-deadline",
     help="Duration in milliseconds that each individual example with a test is not allowed to exceed.",
@@ -448,7 +477,7 @@ with_request_cert_key = click.option(
 @click.option(
     "--hypothesis-phases",
     help="Control which phases should be run.",
-    type=CSVOption(hypothesis.Phase),
+    type=CsvEnumChoice(hypothesis.Phase),
     cls=GroupedOption,
     group=ParameterGroup.hypothesis,
 )
@@ -469,7 +498,7 @@ with_request_cert_key = click.option(
 @click.option(
     "--hypothesis-suppress-health-check",
     help="Comma-separated list of health checks to disable.",
-    type=CSVOption(hypothesis.HealthCheck),
+    type=CsvEnumChoice(hypothesis.HealthCheck),
     cls=GroupedOption,
     group=ParameterGroup.hypothesis,
 )
@@ -484,20 +513,24 @@ with_request_cert_key = click.option(
 @click.option("--no-color", help="Disable ANSI color escape codes.", type=bool, is_flag=True)
 @click.option(
     "--schemathesis-io-token",
-    help="Schemathesis.io authentication token. If present, test run results will be uploaded to Schemathesis.io",
+    help="Schemathesis.io authentication token.",
     type=str,
+    envvar=service.TOKEN_ENV_VAR,
 )
 @click.option(
     "--schemathesis-io-url",
     help="Schemathesis.io base URL.",
     default=service.DEFAULT_URL,
     type=str,
+    envvar=service.URL_ENV_VAR,
 )
+@with_hosts_file
 @click.option("--verbosity", "-v", help="Reduce verbosity of error output.", count=True)
 @click.pass_context
 def run(
     ctx: click.Context,
     schema: str,
+    api_slug: Optional[str],
     auth: Optional[Tuple[str, str]],
     auth_type: str,
     headers: Dict[str, str],
@@ -524,11 +557,13 @@ def run(
     debug_output_file: Optional[click.utils.LazyFile] = None,
     show_errors_tracebacks: bool = False,
     code_sample_style: CodeSampleStyle = CodeSampleStyle.default(),
+    cassette_path: Optional[click.utils.LazyFile] = None,
     store_network_log: Optional[click.utils.LazyFile] = None,
     fixups: Tuple[str] = (),  # type: ignore
     stateful: Optional[Stateful] = None,
     stateful_recursion_limit: int = DEFAULT_STATEFUL_RECURSION_LIMIT,
     force_schema_version: Optional[str] = None,
+    hypothesis_database: Optional[str] = None,
     hypothesis_deadline: Optional[Union[int, NotSet]] = None,
     hypothesis_derandomize: Optional[bool] = None,
     hypothesis_max_examples: Optional[int] = None,
@@ -541,16 +576,55 @@ def run(
     no_color: bool = False,
     schemathesis_io_token: Optional[str] = None,
     schemathesis_io_url: str = service.DEFAULT_URL,
+    hosts_file: PathLike = service.DEFAULT_HOSTS_PATH,
 ) -> None:
     """Perform schemathesis test against an API specified by SCHEMA.
 
     SCHEMA must be a valid URL or file path pointing to an Open API / GraphQL specification.
+
+    API_SLUG is an API identifier to upload data to Schemathesis.io.
     """
     # pylint: disable=too-many-locals
     maybe_disable_color(ctx, no_color)
     check_auth(auth, headers)
     selected_targets = tuple(target for target in targets_module.ALL_TARGETS if target.__name__ in targets)
 
+    if store_network_log and cassette_path:
+        error_message(CASSETTES_PATH_INVALID_USAGE_MESSAGE)
+        sys.exit(1)
+    if store_network_log is not None:
+        click.secho(DEPRECATED_CASSETTE_PATH_OPTION_WARNING, fg="yellow")
+        cassette_path = store_network_log
+
+    schemathesis_io_hostname = urlparse(schemathesis_io_url).netloc
+    token = schemathesis_io_token or service.hosts.get_token(hostname=schemathesis_io_hostname, hosts_file=hosts_file)
+    schema_kind = callbacks.parse_schema_kind(schema, app)
+    callbacks.validate_schema(schema, schema_kind, base_url=base_url, dry_run=dry_run, app=app, api_slug=api_slug)
+    client = None
+    test_run = None
+    if api_slug is not None or schema_kind == callbacks.SchemaInputKind.SLUG:
+        if token is None:
+            hostname = (
+                "Schemathesis.io" if schemathesis_io_hostname == service.DEFAULT_HOSTNAME else schemathesis_io_hostname
+            )
+            raise click.UsageError(
+                "\n\n"
+                f"You are trying to upload data to {hostname}, but your CLI appears to be not authenticated.\n\n"
+                "To authenticate, grab your token from `app.schemathesis.io` and run `st auth login <TOKEN>`\n"
+                "Alternatively, you can pass the token explicitly via the `--schemathesis-io-token` option / "
+                f"`{service.TOKEN_ENV_VAR}` environment variable\n\n"
+                "See https://schemathesis.readthedocs.io/en/stable/service.html for more details"
+            )
+        client = service.ServiceClient(base_url=schemathesis_io_url, token=token)
+        try:
+            test_run = client.create_test_run(schema)
+            if schema_kind == callbacks.SchemaInputKind.SLUG:
+                # Replace config values with ones loaded from the service
+                schema = test_run.config.location
+                base_url = base_url or test_run.config.base_url
+        except requests.HTTPError as exc:
+            handle_service_error(exc)
+
     if "all" in checks:
         selected_checks = checks_module.ALL_CHECKS
     else:
@@ -562,6 +636,7 @@ def run(
         else:
             _fixups.install(fixups)
     hypothesis_settings = prepare_hypothesis_settings(
+        database=hypothesis_database,
         deadline=hypothesis_deadline,
         derandomize=hypothesis_derandomize,
         max_examples=hypothesis_max_examples,
@@ -591,7 +666,7 @@ def run(
         seed=hypothesis_seed,
         exit_first=exit_first,
         dry_run=dry_run,
-        store_interactions=store_network_log is not None,
+        store_interactions=cassette_path is not None,
         checks=selected_checks,
         max_response_time=max_response_time,
         targets=selected_targets,
@@ -602,16 +677,18 @@ def run(
     )
     execute(
         event_stream,
+        hypothesis_settings,
         workers_num,
         show_errors_tracebacks,
         validate_schema,
-        store_network_log,
+        cassette_path,
         junit_xml,
         verbosity,
         code_sample_style,
         debug_output_file,
-        schemathesis_io_token,
         schemathesis_io_url,
+        client,
+        test_run,
     )
 
 
@@ -866,37 +943,41 @@ class OutputStyle(Enum):
 
 def execute(
     event_stream: Generator[events.ExecutionEvent, None, None],
+    hypothesis_settings: hypothesis.settings,
     workers_num: int,
     show_errors_tracebacks: bool,
     validate_schema: bool,
-    store_network_log: Optional[click.utils.LazyFile],
+    cassette_path: Optional[click.utils.LazyFile],
     junit_xml: Optional[click.utils.LazyFile],
     verbosity: int,
     code_sample_style: CodeSampleStyle,
     debug_output_file: Optional[click.utils.LazyFile],
-    schemathesis_io_token: Optional[str],
     schemathesis_io_url: str,
+    client: Optional[service.ServiceClient],
+    test_run: Optional[service.TestRun],
 ) -> None:
     """Execute a prepared runner by drawing events from it and passing to a proper handler."""
     handlers: List[EventHandler] = []
+    service_context = None
+    if client is not None and test_run is not None:
+        service_queue: Queue = Queue()
+        service_context = ServiceContext(url=schemathesis_io_url, queue=service_queue)
+        reporter = service.ServiceReporter(client=client, test_run=test_run, out_queue=service_queue)
+        handlers.append(reporter)
     if junit_xml is not None:
         handlers.append(JunitXMLHandler(junit_xml))
     if debug_output_file is not None:
         handlers.append(DebugOutputHandler(debug_output_file))
-    service_context = None
-    if schemathesis_io_token is not None:
-        service_queue: Queue = Queue()
-        service_context = ServiceContext(url=schemathesis_io_url, queue=service_queue)
-        handlers.append(service.ServiceReporter(service_queue, schemathesis_io_token, schemathesis_io_url))
-    if store_network_log is not None:
+    if cassette_path is not None:
         # This handler should be first to have logs writing completed when the output handler will display statistic
-        handlers.append(cassettes.CassetteWriter(store_network_log))
+        handlers.append(cassettes.CassetteWriter(cassette_path))
     handlers.append(get_output_handler(workers_num))
     execution_context = ExecutionContext(
+        hypothesis_settings=hypothesis_settings,
         workers_num=workers_num,
         show_errors_tracebacks=show_errors_tracebacks,
         validate_schema=validate_schema,
-        cassette_file_name=store_network_log.name if store_network_log is not None else None,
+        cassette_path=cassette_path.name if cassette_path is not None else None,
         junit_xml_file=junit_xml.name if junit_xml is not None else None,
         verbosity=verbosity,
         code_sample_style=code_sample_style,
@@ -928,6 +1009,14 @@ def execute(
     sys.exit(1)
 
 
+def handle_service_error(exc: requests.HTTPError) -> NoReturn:
+    if exc.response.status_code == 404:
+        error_message("API_SLUG not found!")
+    else:
+        output.default.display_service_error(service.Error(exc))
+    sys.exit(1)
+
+
 def get_exit_code(event: events.ExecutionEvent) -> int:
     if isinstance(event, events.Finished):
         if event.has_failures or event.has_errors:
@@ -964,7 +1053,7 @@ def replay(
     """Replay a cassette.
 
     Cassettes in VCR-compatible format can be replayed.
-    For example, ones that are recorded with ``store-network-log`` option of `schemathesis run` command.
+    For example, ones that are recorded with ``store-network-log`` option of `st run` command.
     """
     maybe_disable_color(ctx, no_color)
     click.secho(f"{bold('Replaying cassette')}: {cassette_path}")
@@ -986,6 +1075,81 @@ def replay(
         click.secho(f"  {bold('New status code')} : {replayed.response.status_code}\n")
 
 
+@schemathesis.group(short_help="Authenticate Schemathesis.io.")
+def auth() -> None:
+    pass
+
+
+@auth.command(short_help="Authenticate with a Schemathesis.io host.")
+@click.argument("token", type=str, envvar=service.TOKEN_ENV_VAR)
+@click.option(
+    "--hostname",
+    help="The hostname of the Schemathesis.io instance to authenticate with",
+    type=str,
+    default=service.DEFAULT_HOSTNAME,
+    envvar=service.HOSTNAME_ENV_VAR,
+)
+@click.option(
+    "--protocol",
+    type=click.Choice(["https", "http"]),
+    default=service.DEFAULT_PROTOCOL,
+    envvar=service.PROTOCOL_ENV_VAR,
+)
+@with_request_tls_verify
+@with_hosts_file
+def login(token: str, hostname: str, hosts_file: str, protocol: str, request_tls_verify: bool = True) -> None:
+    """Authenticate with a Schemathesis.io host.
+
+    Example:
+        st auth login MY_TOKEN
+
+    """
+    try:
+        username = service.auth.login(token, hostname, protocol, request_tls_verify)
+        service.hosts.store(token, hostname, hosts_file)
+        success_message(f"Logged in into {hostname} as " + bold(username))
+    except requests.HTTPError as exc:
+        detail = exc.response.json()["detail"]
+        error_message(f"Failed to login into {hostname}: " + bold(detail))
+        sys.exit(1)
+
+
+@auth.command(short_help="Remove authentication for a Schemathesis.io host.")
+@click.option(
+    "--hostname",
+    help="The hostname of the Schemathesis.io instance to authenticate with",
+    type=str,
+    default=service.DEFAULT_HOSTNAME,
+    envvar=service.HOSTNAME_ENV_VAR,
+)
+@with_hosts_file
+def logout(hostname: str, hosts_file: str) -> None:
+    """Remove authentication for a Schemathesis.io host."""
+    result = service.hosts.remove(hostname, hosts_file)
+    if result == service.hosts.RemoveAuth.success:
+        success_message(f"Logged out of {hostname} account")
+    else:
+        if result == service.hosts.RemoveAuth.no_match:
+            warning_message(f"Not logged in to {hostname}")
+        if result == service.hosts.RemoveAuth.no_hosts:
+            warning_message("Not logged in to any hosts")
+        if result == service.hosts.RemoveAuth.error:
+            error_message(f"Failed to read the hosts file. Try to remove {hosts_file}")
+        sys.exit(1)
+
+
+def success_message(message: str) -> None:
+    click.secho(click.style("✔️", fg="green") + f" {message}")
+
+
+def warning_message(message: str) -> None:
+    click.secho(click.style("🟡️", fg="yellow") + f" {message}")
+
+
+def error_message(message: str) -> None:
+    click.secho(f"❌ {message}")
+
+
 def bold(message: str) -> str:
     return click.style(message, bold=True)
 
