@@ -8,11 +8,10 @@ from typing import Any, Dict, Generator, List, Optional, Tuple, Union, cast
 
 import click
 import requests
-from hypothesis import settings
 
 from ... import service
 from ..._compat import metadata
-from ...constants import CodeSampleStyle, __version__
+from ...constants import DISCORD_LINK, CodeSampleStyle, __version__
 from ...models import Response, Status
 from ...runner import events
 from ...runner.serialization import SerializedCase, SerializedError, SerializedTestResult, deduplicate_failures
@@ -133,6 +132,11 @@ def display_errors(context: ExecutionContext, event: events.Finished) -> None:
         click.secho(
             "Add this option to your command line parameters to see full tracebacks: --show-errors-tracebacks", fg="red"
         )
+    click.secho(
+        f"\nIf you need assistance in solving this, feel free to join our Discord server and report it:\n\n"
+        f"  {DISCORD_LINK}\n",
+        fg="red",
+    )
 
 
 def display_single_error(context: ExecutionContext, result: SerializedTestResult) -> bool:
@@ -227,7 +231,7 @@ def display_example(
     click.echo()
     if response is not None and response.body is not None:
         payload = base64.b64decode(response.body).decode(response.encoding or "utf8", errors="replace")
-        click.secho(f"----------\n\nResponse payload: `{payload}`\n", fg="red")
+        click.secho(f"----------\n\nResponse status: {response.status_code}\nResponse payload: `{payload}`\n", fg="red")
     if context.code_sample_style == CodeSampleStyle.python:
         click.secho(f"Run this Python code to reproduce this failure: \n\n    {case.requests_code}\n", fg="red")
     if context.code_sample_style == CodeSampleStyle.curl:
@@ -263,10 +267,10 @@ def display_statistic(context: ExecutionContext, event: events.Finished) -> None
     if total:
         display_checks_statistics(total)
 
-    if context.cassette_file_name:
+    if context.cassette_path:
         click.echo()
         category = click.style("Network log", bold=True)
-        click.secho(f"{category}: {context.cassette_file_name}")
+        click.secho(f"{category}: {context.cassette_path}")
 
     if context.junit_xml_file:
         click.echo()
@@ -294,12 +298,12 @@ def handle_service_integration(context: ExecutionContext) -> None:
             report_title = click.style("Report", bold=True)
             click.echo(f"{report_title}: {event.short_url}")
         if isinstance(event, service.Error):
-            display_service_error(event, context)
+            click.echo()
+            display_service_error(event)
 
 
-def display_service_error(event: service.Error, context: ExecutionContext) -> None:
+def display_service_error(event: service.Error) -> None:
     """Show information about an error during communication with Schemathesis.io."""
-    click.echo()
     if isinstance(event.exception, requests.HTTPError):
         status_code = event.exception.response.status_code
         click.secho(f"Schemathesis.io responded with HTTP {status_code}", fg="red")
@@ -313,7 +317,7 @@ def display_service_error(event: service.Error, context: ExecutionContext) -> No
         elif status_code == 401:
             # Likely an invalid token
             click.secho(
-                "Please, check that you use the proper CLI upload token\n"
+                "Please, check that you use the proper CLI access token\n"
                 "See https://schemathesis.readthedocs.io/en/stable/service.html for more details",
                 fg="red",
             )
@@ -399,13 +403,15 @@ def display_internal_error(context: ExecutionContext, event: events.InternalErro
     click.secho(event.message, fg="red")
     if event.exception:
         if context.show_errors_tracebacks:
-            message = event.exception_with_traceback
+            message = (
+                f"Error: {event.exception_with_traceback}\n"
+                f"Please, consider reporting the traceback below it to our issue tracker: {ISSUE_TRACKER_URL}"
+            )
         else:
-            message = event.exception
-        message = (
-            f"Error: {message}\n"
-            f"Add this option to your command line parameters to see full tracebacks: --show-errors-tracebacks"
-        )
+            message = (
+                f"Error: {event.exception}\n"
+                f"Add this option to your command line parameters to see full tracebacks: --show-errors-tracebacks\n"
+            )
         if event.exception_type == "schemathesis.exceptions.SchemaLoadingError":
             message += "\n" + DISABLE_SCHEMA_VALIDATION_MESSAGE
         click.secho(message, fg="red")
@@ -425,11 +431,7 @@ def handle_initialized(context: ExecutionContext, event: events.Initialized) ->
     )
     click.echo(versions)
     click.echo(f"rootdir: {os.getcwd()}")
-    current_profile = settings._current_profile  # type: ignore[attr-defined]
-    click.echo(
-        f"hypothesis profile '{current_profile}' "  # type: ignore
-        f"-> {settings.get_profile(current_profile).show_changed()}"
-    )
+    click.echo(f"Hypothesis: {context.hypothesis_settings.show_changed()}")
     if event.location is not None:
         click.echo(f"Schema location: {event.location}")
     click.echo(f"Base URL: {event.base_url}")
