@@ -13,8 +13,12 @@ except metadata.PackageNotFoundError:
     __version__ = "dev"
 
 IS_PYTEST_ABOVE_54 = version.parse(pytest.__version__) >= version.parse("5.4.0")
+IS_PYTEST_ABOVE_7 = version.parse(pytest.__version__) >= version.parse("7.0.0")
 
 USER_AGENT = f"schemathesis/{__version__}"
+SCHEMATHESIS_TEST_CASE_HEADER = "X-Schemathesis-TestCaseId"
+HYPOTHESIS_IN_MEMORY_DATABASE_IDENTIFIER = ":memory:"
+DISCORD_LINK = "https://discord.gg/R9ASRAmHnA"
 # Maximum test running time
 DEFAULT_DEADLINE = 15000  # pragma: no mutate
 DEFAULT_RESPONSE_TIMEOUT = 10000  # pragma: no mutate
