@@ -28,6 +28,7 @@ from typing import (
     cast,
 )
 from urllib.parse import quote, unquote, urljoin, urlparse, urlsplit, urlunsplit
+from uuid import uuid4
 
 import attr
 import curlify
@@ -39,8 +40,10 @@ from requests.structures import CaseInsensitiveDict
 from starlette.testclient import TestClient as ASGIClient
 
 from . import failures, serializers
+from .auth import AuthStorage
 from .constants import (
     DEFAULT_RESPONSE_TIMEOUT,
+    SCHEMATHESIS_TEST_CASE_HEADER,
     SERIALIZERS_SUGGESTION_MESSAGE,
     USER_AGENT,
     CodeSampleStyle,
@@ -51,6 +54,7 @@ from .exceptions import (
     FailureContext,
     InvalidSchema,
     SerializationNotPossible,
+    deduplicate_failed_checks,
     get_grouped_exception,
     get_timeout_error,
 )
@@ -62,6 +66,7 @@ from .utils import (
     NOT_SET,
     GenericResponse,
     WSGIResponse,
+    copy_response,
     deprecated_property,
     get_response_payload,
     maybe_set_assertion_message,
@@ -79,6 +84,9 @@ class CaseSource:
     case: "Case" = attr.ib()  # pragma: no mutate
     response: GenericResponse = attr.ib()  # pragma: no mutate
 
+    def partial_deepcopy(self) -> "CaseSource":
+        return self.__class__(case=self.case.partial_deepcopy(), response=copy_response(self.response))
+
 
 def cant_serialize(media_type: str) -> NoReturn:  # type: ignore
     """Reject the current example if we don't know how to send this data to the application."""
@@ -106,6 +114,8 @@ class Case:  # pylint: disable=too-many-public-methods
     media_type: Optional[str] = attr.ib(default=None)  # pragma: no mutate
     # The way the case was generated (None for manually crafted ones)
     data_generation_method: Optional[DataGenerationMethod] = attr.ib(default=None)  # pragma: no mutate
+    # Unique test case identifier
+    id: str = attr.ib(factory=lambda: uuid4().hex, eq=False)  # pragma: no mutate
 
     def __repr__(self) -> str:
         parts = [f"{self.__class__.__name__}("]
@@ -157,6 +167,9 @@ class Case:  # pylint: disable=too-many-public-methods
             # in the parameters list.
             # When `exc` is formatted, it is the missing key name in quotes. E.g. 'id'
             raise InvalidSchema(f"Path parameter {exc} is not defined") from exc
+        except ValueError as exc:
+            # A single unmatched `}` inside the path template may cause this
+            raise InvalidSchema(f"Malformed path template: `{self.path}`\n\n  {exc}") from exc
 
     def get_full_base_url(self) -> Optional[str]:
         """Create a full base url, adding "localhost" for WSGI apps."""
@@ -259,6 +272,7 @@ class Case:  # pylint: disable=too-many-public-methods
         if headers:
             final_headers.update(headers)
         final_headers.setdefault("User-Agent", USER_AGENT)
+        final_headers.setdefault(SCHEMATHESIS_TEST_CASE_HEADER, self.id)
         return final_headers
 
     def _get_serializer(self) -> Optional[Serializer]:
@@ -412,16 +426,19 @@ class Case:  # pylint: disable=too-many-public-methods
         from .checks import ALL_CHECKS  # pylint: disable=import-outside-toplevel
 
         checks = checks or ALL_CHECKS
-        errors = []
+        failed_checks = []
         for check in chain(checks, additional_checks):
+            copied_case = self.partial_deepcopy()
+            copied_response = copy_response(response)
             try:
-                check(response, self)
+                check(copied_response, copied_case)
             except AssertionError as exc:
                 maybe_set_assertion_message(exc, check.__name__)
-                errors.append(exc)
-        if errors:
-            exception_cls = get_grouped_exception(self.operation.verbose_name, *errors)
-            formatted_errors = "\n\n".join(f"{idx}. {error.args[0]}" for idx, error in enumerate(errors, 1))
+                failed_checks.append(exc)
+        failed_checks = list(deduplicate_failed_checks(failed_checks))
+        if failed_checks:
+            exception_cls = get_grouped_exception(self.operation.verbose_name, *failed_checks)
+            formatted_failures = "\n\n".join(f"{idx}. {error.args[0]}" for idx, error in enumerate(failed_checks, 1))
             code_sample_style = (
                 CodeSampleStyle.from_str(code_sample_style)
                 if code_sample_style is not None
@@ -430,7 +447,11 @@ class Case:  # pylint: disable=too-many-public-methods
             code_message = self._get_code_message(code_sample_style, response.request)
             payload = get_response_payload(response)
             raise exception_cls(
-                f"\n\n{formatted_errors}\n\n----------\n\nResponse payload: `{payload}`\n\n{code_message}"
+                f"\n\n{formatted_failures}\n\n"
+                f"----------\n\n"
+                f"Response status: {response.status_code}\n"
+                f"Response payload: `{payload}`\n\n"
+                f"{code_message}"
             )
 
     def _get_code_message(self, code_sample_style: CodeSampleStyle, request: requests.PreparedRequest) -> str:
@@ -468,6 +489,7 @@ class Case:  # pylint: disable=too-many-public-methods
             operation=self.operation.partial_deepcopy(),
             data_generation_method=self.data_generation_method,
             media_type=self.media_type,
+            source=self.source if self.source is None else self.source.partial_deepcopy(),
             path_parameters=deepcopy(self.path_parameters),
             headers=deepcopy(self.headers),
             cookies=deepcopy(self.cookies),
@@ -627,10 +649,11 @@ class APIOperation(Generic[P, C]):
     def as_strategy(
         self,
         hooks: Optional["HookDispatcher"] = None,
+        auth_storage: Optional[AuthStorage] = None,
         data_generation_method: DataGenerationMethod = DataGenerationMethod.default(),
     ) -> st.SearchStrategy:
         """Turn this API operation into a Hypothesis strategy."""
-        strategy = self.schema.get_case_strategy(self, hooks, data_generation_method)
+        strategy = self.schema.get_case_strategy(self, hooks, auth_storage, data_generation_method)
 
         def _apply_hooks(dispatcher: HookDispatcher, _strategy: st.SearchStrategy[Case]) -> st.SearchStrategy[Case]:
             for hook in dispatcher.get_all_by_name("before_generate_case"):
