@@ -4,7 +4,6 @@ import threading
 import time
 import uuid
 from contextlib import contextmanager
-from copy import copy, deepcopy
 from types import TracebackType
 from typing import Any, Callable, Dict, Generator, Iterable, List, Optional, Type, Union, cast
 from warnings import WarningMessage, catch_warnings
@@ -18,6 +17,7 @@ from hypothesis_jsonschema._canonicalise import HypothesisRefResolutionError
 from requests.auth import HTTPDigestAuth, _basic_auth_str
 
 from ... import failures, hooks
+from ...auth import unregister as unregister_auth
 from ...constants import (
     DEFAULT_STATEFUL_RECURSION_LIMIT,
     RECURSIVE_REFERENCE_ERROR_MESSAGE,
@@ -44,6 +44,7 @@ from ...utils import (
     Ok,
     WSGIResponse,
     capture_hypothesis_output,
+    copy_response,
     format_exception,
     maybe_set_assertion_message,
 )
@@ -75,6 +76,9 @@ class BaseRunner:
         return EventStream(self._generate_events(event), event)
 
     def _generate_events(self, stop_event: threading.Event) -> Generator[events.ExecutionEvent, None, None]:
+        # If auth is explicitly provided, then the global provider is ignored
+        if self.auth is not None:
+            unregister_auth()
         results = TestResultSet()
 
         initialized = events.Initialized.from_schema(schema=self.schema, count_operations=self.count_operations)
@@ -400,18 +404,6 @@ def deduplicate_errors(errors: List[Exception]) -> Generator[Exception, None, No
         yield error
 
 
-def _copy_response(response: GenericResponse) -> GenericResponse:
-    if isinstance(response, requests.Response):
-        copied_response = deepcopy(response)
-        setattr(copied_response, "raw", response.raw)
-        return copied_response
-    # Can't deepcopy WSGI response due to generators inside (`response.freeze` doesn't completely help)
-    response.freeze()
-    copied_response = copy(response)
-    copied_response.request = deepcopy(response.request)
-    return copied_response
-
-
 def run_checks(
     case: Case,
     checks: Iterable[CheckFunction],
@@ -426,7 +418,7 @@ def run_checks(
     for check in checks:
         check_name = check.__name__
         copied_case = case.partial_deepcopy()
-        copied_response = _copy_response(response)
+        copied_response = copy_response(response)
         try:
             skip_check = check(copied_response, copied_case)
             if not skip_check:
