@@ -31,6 +31,7 @@ from hypothesis.strategies import SearchStrategy
 from requests.structures import CaseInsensitiveDict
 
 from ... import failures
+from ...auth import AuthStorage
 from ...constants import HTTP_METHODS, DataGenerationMethod
 from ...exceptions import (
     InvalidSchema,
@@ -320,9 +321,12 @@ class BaseOpenAPISchema(BaseSchema):
         self,
         operation: APIOperation,
         hooks: Optional[HookDispatcher] = None,
+        auth_storage: Optional[AuthStorage] = None,
         data_generation_method: DataGenerationMethod = DataGenerationMethod.default(),
     ) -> SearchStrategy:
-        return get_case_strategy(operation=operation, hooks=hooks, data_generation_method=data_generation_method)
+        return get_case_strategy(
+            operation=operation, auth_storage=auth_storage, hooks=hooks, data_generation_method=data_generation_method
+        )
 
     def get_parameter_serializer(self, operation: APIOperation, location: str) -> Optional[Callable]:
         definitions = [item for item in operation.definition.resolved.get("parameters", []) if item["in"] == location]
@@ -368,6 +372,7 @@ class BaseOpenAPISchema(BaseSchema):
         status_code: Union[str, int],
         parameters: Optional[Dict[str, str]] = None,
         request_body: Any = None,
+        name: Optional[str] = None,
     ) -> None:
         """Add a new Open API link to the schema definition.
 
@@ -380,6 +385,7 @@ class BaseOpenAPISchema(BaseSchema):
             expression string.
         :param request_body: A literal value or runtime expression to use as a request body when
             calling the target operation.
+        :param str name: Explicit link name.
 
         .. code-block:: python
 
@@ -406,7 +412,13 @@ class BaseOpenAPISchema(BaseSchema):
                     if method.upper() == source.method.upper():
                         found = True
                         links.add_link(
-                            definition["responses"], self.links_field, parameters, request_body, status_code, target
+                            responses=definition["responses"],
+                            links_field=self.links_field,
+                            parameters=parameters,
+                            request_body=request_body,
+                            status_code=status_code,
+                            target=target,
+                            name=name,
                         )
                     # If methods are behind a reference, then on the next resolving they will miss the new link
                     # Therefore we need to modify it this way
